/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const { Messages } = require('@salesforce/core');
Messages.importMessagesDirectory(__dirname);
module.exports = function (_execCommand) {
    const messagesHammerTestReport = Messages.loadMessages('salesforce-alm', 'package_hammertest_report');
    return {
        description: messagesHammerTestReport.getMessage('cliDescription'),
        longDescription: messagesHammerTestReport.getMessage('cliLongDescription'),
        help: messagesHammerTestReport.getMessage('help'),
        supportsTargetUsername: true,
        flags: [
            {
                name: 'requestid',
                char: 'i',
                description: messagesHammerTestReport.getMessage('requestid'),
                longDescription: messagesHammerTestReport.getMessage('requestidLong'),
                hasValue: true,
                required: true,
                type: 'id'
            },
            {
                name: 'summary',
                char: 's',
                description: messagesHammerTestReport.getMessage('summary'),
                longDescription: messagesHammerTestReport.getMessage('summaryLong'),
                hasValue: false,
                required: false,
                type: 'boolean'
            }
        ],
        hidden: true,
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const HammerTestReportCommand = require(path.join('..', '..', 'lib', 'package', 'hammerTestReportCommand'));
            return _execCommand(new HammerTestReportCommand(), context);
        }
    };
};

//# sourceMappingURL=package_hammertest_report.js.map
