/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
/* eslint global-require: 0 */
'use strict';
const path = require('path');
const { Messages } = require('@salesforce/core');
Messages.importMessagesDirectory(__dirname);
module.exports = function (_execCommand) {
    const messagesHammerTestReport = Messages.loadMessages('salesforce-alm', 'package_hammertest_run');
    return {
        description: messagesHammerTestReport.getMessage('cliDescription'),
        longDescription: messagesHammerTestReport.getMessage('cliLongDescription'),
        help: messagesHammerTestReport.getMessage('help'),
        supportsTargetUsername: true,
        flags: [
            {
                name: 'packageversionid',
                char: 'i',
                description: messagesHammerTestReport.getMessage('packageversionid'),
                longDescription: messagesHammerTestReport.getMessage('packageversionidLong'),
                hasValue: true,
                required: true,
                type: 'id'
            },
            {
                name: 'subscriberorg',
                char: 's',
                description: messagesHammerTestReport.getMessage('subscriberorg'),
                longDescription: messagesHammerTestReport.getMessage('subscriberorgLong'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'subscriberfile',
                char: 'f',
                description: messagesHammerTestReport.getMessage('subscriberfile'),
                longDescription: messagesHammerTestReport.getMessage('subscriberfileLong'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'scheduledrundatetime',
                char: 'd',
                description: messagesHammerTestReport.getMessage('scheduledrundatetime'),
                longDescription: messagesHammerTestReport.getMessage('scheduledrundatetimeLong'),
                hasValue: true,
                required: false,
                type: 'string'
            },
            {
                name: 'preview',
                char: 'p',
                description: messagesHammerTestReport.getMessage('preview'),
                longDescription: messagesHammerTestReport.getMessage('previewLong'),
                hasValue: false,
                required: false,
                type: 'boolean'
            },
            {
                name: 'apextests',
                char: 't',
                description: messagesHammerTestReport.getMessage('apextests'),
                longDescription: messagesHammerTestReport.getMessage('apextestsLong'),
                hasValue: false,
                required: false,
                type: 'boolean'
            }
        ],
        hidden: true,
        /**
         * the heroku cli hook
         * @param context - the cli context
         * @returns {Promise}
         */
        run(context) {
            const HammerTestRunCommand = require(path.join('..', '..', 'lib', 'package', 'hammerTestRunCommand'));
            return _execCommand(new HammerTestRunCommand(), context);
        }
    };
};

//# sourceMappingURL=package_hammertest_run.js.map
