"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@salesforce/core");
const _ = require('lodash');
const Config = require('./configApi').Config;
class MetadataConnection extends core_1.Connection {
    // TODO: A method should be added to jsforce for deployRecentValidation()
    _mdapiSoapDeployRecentValidation(options, connection) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            try {
                result = yield connection.metadata['_invoke']("deployRecentValidation", {
                    validationId: options.validateddeployrequestid
                });
            }
            catch (err) {
                throw err;
            }
            return result;
        });
    }
    _mdapiRestDeployRecentValidation(options, connection) {
        return __awaiter(this, void 0, void 0, function* () {
            const validateddeployrequestid = options.validateddeployrequestid;
            const url = `${connection.instanceUrl}/services/data/v${connection.getApiVersion()}/metadata/deployRequest`;
            const messageBody = JSON.stringify({ validatedDeployRequestId: validateddeployrequestid });
            const requestInfo = {
                method: 'POST',
                url,
                body: messageBody
            };
            const requestOptions = { headers: 'json' };
            let body;
            try {
                body = yield connection.request(requestInfo, requestOptions);
            }
            catch (err) {
                if (err.name === 'API_DISABLED_FOR_ORG') {
                    throw core_1.SfdxError.create('salesforce-alm', 'mdapi_deploy', 'mdDeployCommandCliNoRestDeploy');
                }
                else {
                    throw err;
                }
            }
            return body;
        });
    }
    ;
}
exports.MetadataConnection = MetadataConnection;
// Get a @salesforce/core Connection, which extends jsforce.Connection.
function getMetadataConnection(orgApi) {
    return __awaiter(this, void 0, void 0, function* () {
        const connection = yield core_1.Connection.create({
            authInfo: yield core_1.AuthInfo.create({ username: orgApi.getName(), oauth2Options: orgApi.authConfig })
        });
        connection.setApiVersion(new Config().getApiVersion());
        return connection;
    });
}
exports.getMetadataConnection = getMetadataConnection;
;
//metadata api deploy recent validation; options contains the validated job ID to deployed
function mdapiDeployRecentValidation(orgApi, options) {
    return __awaiter(this, void 0, void 0, function* () {
        let connection = yield getMetadataConnection(orgApi);
        const restDeploy = isRestDeploy(orgApi);
        if (restDeploy) {
            this.logger = yield core_1.Logger.child('*** Deploying with REST ***');
            return MetadataConnection.prototype._mdapiRestDeployRecentValidation(options, connection);
        }
        else {
            return MetadataConnection.prototype._mdapiSoapDeployRecentValidation(options, connection);
        }
    });
}
exports.mdapiDeployRecentValidation = mdapiDeployRecentValidation;
;
function isRestDeploy(orgApi) {
    const restDeploy = _.get(orgApi, 'aggregator.config.restDeploy');
    return !!(restDeploy && restDeploy.toString() === 'true');
}
exports.isRestDeploy = isRestDeploy;
;
function isRestDeployWithWaitZero(orgApi, options) {
    const appConfig = orgApi.getConfig().getAppConfigIfInWorkspace();
    const restDeploy = appConfig && appConfig.restDeploy;
    return !!(restDeploy && restDeploy.toString() === 'true' && options.wait === 0);
}
exports.isRestDeployWithWaitZero = isRestDeployWithWaitZero;
;
function validateExclusiveFlag(options, param1, param2) {
    if (options[param1] && options[param2]) {
        throw core_1.SfdxError.create('salesforce-alm', 'mdapi_deploy', 'mdapiCliExclusiveFlagError', [param1, param2]);
    }
}
exports.validateExclusiveFlag = validateExclusiveFlag;
;

//# sourceMappingURL=mdApiUtil.js.map
