/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require('path');
const core_1 = require("@salesforce/core");
const Config = require(path.join(__dirname, '..', 'configApi')).Config;
const DeployReport = require(path.join(__dirname, '..', 'mdapiDeployReportApi'));
/**
 * API that wraps Metadata API to cancel a deployment from a given org.
 *
 * @param force
 * @constructor
 */
class MdapiDeployCancel {
    constructor(org) {
        this._reporter = new DeployReport(org);
    }
    // Get a @salesforce/core Connection, which extends jsforce.Connection.
    _getCoreConnection(username, authConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            const conn = yield core_1.Connection.create({
                authInfo: yield core_1.AuthInfo.create({ username, oauth2Options: authConfig })
            });
            conn.setApiVersion(new Config().getApiVersion());
            return conn;
        });
    }
    ;
    _checkCancelStatus(result, options) {
        options.deprecatedStatusRequest = !!options.jobid;
        options.jobid = options.jobid || result.id;
        options.result = result;
        return this._reporter.report(options);
    }
    ;
    cancel(orgApi, options) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger = yield core_1.Logger.child('md-deploy-cancel');
            const connection = yield this._getCoreConnection(orgApi.getName(), orgApi.authConfig);
            try {
                // TODO: A method should be added to jsforce for cancelDeploy()
                const result = yield connection.metadata["_invoke"]("cancelDeploy", { id: options.jobid });
                return yield this._checkCancelStatus(result, options);
            }
            catch (err) {
                throw core_1.SfdxError.create('salesforce-alm', 'mdapi_cancel', 'CancelFailed', [err.message]);
            }
        });
    }
}
exports.MdapiDeployCancel = MdapiDeployCancel;

//# sourceMappingURL=mdapiDeployCancel.js.map
