/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const core_1 = require("@salesforce/core");
const mdapiDeployCancel_1 = require("../mdapi/mdapiDeployCancel");
const sourceUtil_1 = require("../source/sourceUtil");
const Stash = require(path.join(__dirname, '..', 'stash'));
core_1.Messages.importMessagesDirectory(__dirname);
class MdapiCancelCommand {
    /**
     * Executes the mdapi deploy cancel command
     * @param context - the cli context
     * @returns {Promise}
     */
    execute(context) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger = yield core_1.Logger.child('mdapi:deploy:cancel');
            return yield new mdapiDeployCancel_1.MdapiDeployCancel(this.org).cancel(this.org, context);
        });
    }
    /**
     * Validates the mdapi deploy cancel command parameters
     * @param context - the cli context
     * @returns {Promise}
     */
    validate(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = context.flags;
            this.org = context.org;
            let stashedValues = yield Stash.list(Stash.Commands.MDAPI_DEPLOY);
            if (!options.jobid) {
                options.jobid = stashedValues.jobid;
            }
            if (!options.jobid) {
                throw core_1.SfdxError.create('salesforce-alm', 'mdapi_cancel', 'MissingRequiredParameter');
            }
            // Validate the wait param if set and convert to an integer.
            sourceUtil_1.parseWaitParam(options);
            return Promise.resolve(options);
        });
    }
}
exports.MdapiCancelCommand = MdapiCancelCommand;

//# sourceMappingURL=mdapiDeployCancelCommand.js.map
