"use strict";
/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require('fs');
// 3pp
const mkdirp = require('mkdirp');
// Local
const logger = require(path.join(__dirname, 'logApi'));
const almError = require(path.join(__dirname, 'almError'));
const mdApiUtil = require(path.join(__dirname, 'mdApiUtil'));
/**
 * API that wraps Metadata API to retrieve describemetadata result.
 *
 * @param force
 * @constructor
 */
class MdDescribemetadataApi {
    constructor(org) {
        this.org = org;
        this.force = org.force;
        this.logger = logger.child('md-describemetadata');
    }
    // retreive source from org
    retrieve(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = context.flags;
            // set target org, org other than workspace defined org
            const orgApi = this.org;
            if (options.resultfile) {
                this.retrieveTargetPath = path.resolve(options.resultfile);
            }
            const retrieveOptions = yield this.formatRetrieveOptions(options);
            const result = yield this.retrieveDescribemetadata(orgApi, retrieveOptions);
            if (this.retrieveTargetPath) {
                return this.createOutputJSONResultFile(this.retrieveTargetPath, result, this);
            }
            else {
                this.print(result);
                return result;
            }
        });
    }
    retrieveDescribemetadata(orgApi, retrieveOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            const connection = yield mdApiUtil.getMetadataConnection(orgApi);
            return connection.metadata.describe(retrieveOptions.apiVersion);
        });
    }
    createOutputJSONResultFile(retrieveTargetPath, resultJson, mdApi) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                fs.access(path.dirname(mdApi.retrieveTargetPath));
            }
            catch (err) {
                mkdirp.sync(path.dirname(mdApi.retrieveTargetPath));
            }
            const fileName = retrieveTargetPath;
            const json = JSON.stringify(resultJson);
            yield fs.writeFile(fileName, json);
            this.print(`Wrote result file to ${fileName}.`);
            return { 'message': `Wrote result file to ${fileName}.` };
        });
    }
    formatRetrieveOptions(options) {
        const retrieveOptions = {};
        retrieveOptions.apiVersion = options.apiversion || this.force.config.getApiVersion();
        retrieveOptions.resultfile = options.resultfile;
        retrieveOptions.targetusername = options.targetusername;
        return retrieveOptions;
    }
    print(message) {
        this.logger.log(message);
    }
    validate(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = context.flags;
            const currentApiVersion = this.force.config.getApiVersion();
            if (options.apiversion && (isNaN(+options.apiversion) || +options.apiversion < 0 || +options.apiversion > currentApiVersion)) {
                throw (almError('mdDescribeMetadataCommandCliInvalidApiVersionError', currentApiVersion));
            }
            if (options.resultfile) {
                const retrieveTargetPath = path.resolve(options.resultfile);
                try {
                    const data = fs.statSync(retrieveTargetPath);
                    if (!data.isFile()) {
                        throw almError('InvalidArgumentFilePath', ['resultfile', retrieveTargetPath]);
                    }
                }
                catch (err) {
                    if (err.code !== 'ENOENT') {
                        throw err;
                    }
                }
            }
        });
    }
}
exports.MdDescribemetadataApi = MdDescribemetadataApi;

//# sourceMappingURL=mdapiDescribemetadataApi.js.map
