/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// Node
// Local
const HAMMER_TEST = 'hammer-test';
const RESULT = 'result';
class HammerTestApi {
    constructor(org) {
        this.org = org;
    }
    /**
     * Makes a new ISV Hammer Request
     *
     * @param {string} packageVersionId
     * @param {string list} subscriberOrgIds
     * @param {datetime} scheduledDateTime
     * @param {boolean} isNextSalesforceVersion
     *
     * @returns result structured as json data
     */
    makeNewHammerRequest(apvId, subOrgs, scheduledTime, isNextSalesforceVersion, isRunApexTests) {
        return __awaiter(this, void 0, void 0, function* () {
            const isvHammerRunRequest = {
                packageVersionId: apvId,
                subscriberOrgIds: subOrgs,
                scheduledDateTime: scheduledTime,
                isPreviewVersion: isNextSalesforceVersion,
                isExecuteApexTests: isRunApexTests
            };
            const result = this._calloutNewHammerRequest(isvHammerRunRequest);
            return result;
        });
    }
    /**
     * Fetches statuses of existing hammerTest runs for a packageVersionId
     * @param {string} packageVersionId
     */
    viewHammerRequests(packageVersionId) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            if (packageVersionId !== undefined) {
                result = this._calloutViewHammerRequests(packageVersionId);
            }
            else {
                result = this._calloutViewAllHammerRequests();
            }
            return result;
        });
    }
    /**
     * Fetches statuses of existing hammerTest runs for a packageVersionId
     * @param {string} packageVersionId
     */
    viewHammerTestResult(requestId) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = this._calloutViewHammerTestResult(requestId);
            return result;
        });
    }
    _calloutNewHammerRequest(isvHammerRunRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.org.force.connectApiPost(this.org, `${HAMMER_TEST}`, isvHammerRunRequest);
        });
    }
    _calloutViewHammerRequests(packageVersionId) {
        return __awaiter(this, void 0, void 0, function* () {
            const resource = `${HAMMER_TEST}/?packageVersionId=${packageVersionId}`;
            return this.org.force.connectApiGet(this.org, resource);
        });
    }
    _calloutViewAllHammerRequests() {
        return __awaiter(this, void 0, void 0, function* () {
            const resource = `${HAMMER_TEST}`;
            return this.org.force.connectApiGet(this.org, resource);
        });
    }
    _calloutViewHammerTestResult(requestId) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.org.force.connectApiGet(this.org, `${HAMMER_TEST}/${RESULT}/${requestId}`);
        });
    }
}
module.exports = HammerTestApi;

//# sourceMappingURL=hammerTestApi.js.map
