/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
// Node
const path = require('path');
const { Messages } = require('@salesforce/core');
// Local
const logger = require(path.join(__dirname, '..', 'logApi'));
Messages.importMessagesDirectory(__dirname);
const hammerTestUtils = require(path.join(__dirname, 'hammerTestUtils'));
const HammerTestApi = require(path.join(__dirname, 'hammerTestApi'));
const messagesHammerTestList = Messages.loadMessages('salesforce-alm', 'package_hammertest_list');
class HammerTestListCommand {
    constructor() {
        this.logger = logger.child('package:hammertest:list');
    }
    execute(context) {
        this.hammerTestApi = new HammerTestApi(context.org);
        const packageVersionId = context.flags.packageversionid;
        if (packageVersionId !== undefined) {
            hammerTestUtils.validateSubscriberPackageVersionId(packageVersionId);
            logger.debug(`APV ID: ${packageVersionId}`);
        }
        else {
            logger.debug(`APV ID: ${packageVersionId}; fetching all isv hammer requests`);
        }
        const result = this.hammerTestApi.viewHammerRequests(packageVersionId);
        return result;
    }
    /**
     * returns a human readable message for a cli output
     * @param result - the data representing the Package Version
     * @returns {string}
     */
    getHumanSuccessMessage(result) {
        const data = result.requests.map(req => ({ requestId: req.requestId,
            status: req.status,
            packageVersionId: req.allPackageVersionId,
            createdBy: req.createdBy,
            createdDate: req.createdDate,
            isExecuteApexTests: req.isExecuteApexTests.toString(),
            isNextSalesforceVersion: req.isNextSalesforceVersion.toString(),
            lastModified: req.lastModified,
            lastModifiedBy: req.lastModifiedBy,
            scheduledDateTime: req.scheduledDateTime }));
        this.logger.table(data, { columns: [
                { key: 'requestId', label: 'RequestId' },
                { key: 'status', label: 'Status' },
                { key: 'packageVersionId', label: 'PackageVersionId' },
                { key: 'createdBy', label: 'CreatedBy' },
                { key: 'createdDate', label: 'CreatedDate' },
                { key: 'isExecuteApexTests', label: 'IsExecuteApexTests' },
                { key: 'isNextSalesforceVersion', label: 'IsNextSalesforceVersion' },
                { key: 'lastModified', label: 'LastModified' },
                { key: 'lastModifiedBy', label: 'LastModifiedBy' },
                { key: 'scheduledDateTime', label: 'ScheduledDateTime' }
            ] });
        return messagesHammerTestList.getMessage('humanSuccess');
    }
}
module.exports = HammerTestListCommand;

//# sourceMappingURL=hammerTestListCommand.js.map
